/*
                           Copyright (C) 1995 
             John R.Callahan, Sudhakar Ramakrishnan, Sun Wei.
	         Web Integrated Software Project 
                   Management and Metrics Tool
                           (WISE)

WISE [both binary and source] (hereafter, Software) is 
copyrighted by John R.Callahan, Sudhakar Ramakrishnan , Sun Wei and 
ownership remains with the authors.

The authors grant you (hereafter, Licensee), a license to use the Software
for academic, research and internal business purposes only, without a
fee.  Licensee may distribute the binary to third parties providing 
that the copyright notice and this statement appears on all copies and
that no charge is associated with such copies. 

Licensee may make derivative works.  However, if Licensee distributes
any derivative work based on or derived from the Software, then
Licensee will (1) notify the authors regarding its distribution of 
the derivative work, and (2) clearly notify users that such derivative 
work is a modified version and not the original WISE tool distributed 
by the authors.

Any Licensee wishing to make commercial use of the Software should
contact the authors to negotiate an appropriate license for such
commercial use.  Commercial use includes (1) integration of all or
part of the source code into a product for sale or license by or on
behalf of licensee to third parties, or (2) distribution of the binary
code or source code to third parties that need it to utilize a
commercial product sold or licensed by or on behalf of Licensee.

THE AUTHORS MAKE NO REPRESENTATIONS ABOUT THE SUITABILITY OF THIS 
SOFTWARE FOR ANY PURPOSE.  IT IS PROVIDED "AS IS" WITHOUT EXPRESS OR 
IMPLIED WARRANTY.  THE AUTHORS SHALL NOT BE LIABLE FOR ANY DAMAGES
SUFFERED BY USERS OF THIS SOFTWARE.

By using or copying this Software, Licensee agrees to abide by the
copyright law and all other applicable laws of the U.S., including but
not limited, to, export control laws, and the terms of this license.
The authors shall have the right to terminate this license immediately by
written notice upon Licensee's breach of, or non-compliance with, any
of its terms.  Licensee may be held legally responsible for any
copyright infringement that is caused, directly or indirectly, by
Licensee's failure to abide by the terms of this license.

Direct notices to:
	
	John R.Callahan 
	886 Chestnut Ridge Road
	Concurrent Engineering Research Center
	West Virginia University
	Morgantown, WV 26505
	USA

	phone:	(304) 293-7226
	email:	callahan@cerc.wvu.edu
*/

#include <stdio.h>
#include "nytags.h"
#include "config.h"

extern long yylineno;

int
wise_print(char* s)
{
  if(s != NULL) fputs(s,stdout);
  return 1;
}

yyerror()
{
  fprintf(stderr,"syntax error on line %d\n",yylineno);
  exit(-1);
}

#define CREATE_DATABASE 1
#define CREATE_HEADER 2
#define CREATE_INIT 3
#define CREATE_NAMES 4 
#define CREATE_DUMP 5 
#define CREATE_USERS 6
#define CREATE_ACCESS 7

char* msqldbname = "";
char* currentaction = "";
char* msqlcommand = "";

main(int argc,char** argv)
{
  int i;
  int generate=CREATE_HEADER;
  int wisedebug=0;

  for(i=1;i < argc;i++) {
    if(argv[i][0] == '-') {
      switch(argv[i][1]) {
      case 'd':
	wisedebug = !wisedebug;
	break;
      case 'c':
	generate = CREATE_DATABASE;
	currentaction = "create";
	if(i+1 < argc) msqldbname = argv[i+1];
	else { fprintf(stderr,"must supply a database name!\n"); exit(-1); }
	break;
      case 'n':
	generate = CREATE_NAMES;
	break;
      case 'i':
	generate = CREATE_INIT; 
	currentaction = "initialize";
	if(i+1 < argc) msqldbname = argv[i+1];
	else { fprintf(stderr,"must supply msql binary path!\n"); exit(-1); }
	if(i+2 < argc) msqlcommand = argv[i+2];
	break;
      case 'u':
	generate = CREATE_USERS;
	if(i+1 < argc) msqldbname = argv[i+1];
	else { fprintf(stderr,"must supply msql binary path!\n"); exit(-1); }
	break;
      case 'h':
	generate = CREATE_HEADER;
	break;
      case 'x':
	generate = CREATE_DUMP;
	if(i+1 < argc) msqldbname = argv[i+1];
	else { fprintf(stderr,"must supply msql binary path!\n"); exit(-1); }
	break;
      case 'a':
	generate = CREATE_ACCESS;
	break;
      default: fprintf(stderr,"%s is not a valid option - use -[dcniuhx]\n",argv[i]); exit(-1);
      }
    }
  }

  yyparse();

  switch(generate) {
  case CREATE_HEADER:
    printf("#ifndef WISE\n");
    printf("#define WISE\n\n");
    printf("#define WISEDEBUG\t%d\n\n",wisedebug);
    nyprint(wise_print,WISE,NY_SELECT,NY_NORMAL);
    printf("#include \"wiseproto.h\"\n\n");
    printf("#endif WISEMAIN\n");
    break;
  case CREATE_INIT:
    printf("#!/bin/csh -f\n");
    nyprint(wise_print,SCRIPT,NY_SELECT,NY_NORMAL);
    break;
  case CREATE_NAMES:
    printf("#!/bin/csh -f\n");
    nyprint(wise_print,NAMES,NY_SELECT,NY_NORMAL);
    break;
  case CREATE_DATABASE:
    nyprint(wise_print,DATABASE,NY_SELECT,NY_NORMAL);
    break;
  case CREATE_USERS:
    printf("#!/bin/csh -f\n");
    printf("echo -n \"Do you want to create a .htaccess file? [y/n/q] \"\n");
    printf("if ($< != 'y') then\n");
    printf("  exit\n");
    printf("endif\n");
    printf("echo \"AuthUserFile %s/.htpasswd\" > ../cgi-bin/.htaccess\n",TOPLEVEL);
    printf("echo \"AuthGroupFile /dev/null\" >> ../cgi-bin/.htaccess\n");
    printf("echo \"AuthName WisePassword\" >> ../cgi-bin/.htaccess\n");
    printf("echo \"AuthType Basic\" >> ../cgi-bin/.htaccess\n");
    printf("echo \"<Limit GET POST>\" >> ../cgi-bin/.htaccess\n");
    printf("echo \"order deny,allow\" >> ../cgi-bin/.htaccess\n");
    nyprint(wise_print,USERS,NY_SELECT,NY_NORMAL);
    printf("echo \"</Limit>\" >> ../cgi-bin/.htaccess\n");
    break;
  case CREATE_DUMP:
    printf("#!/bin/csh -f\n");
    printf("setenv TODAY `date '+%%y-%%m-%%d'`\n");
    nyprint(wise_print,DUMP,NY_SELECT,NY_NORMAL);
    printf("echo \"done.\"\n");
    break;
  case CREATE_ACCESS:
    printf("#\n# Automatically generated MSQL access file\n#\n\n");
    nyprint(wise_print,MSQLA,NY_SELECT,NY_NORMAL);
    printf("database=*\nread=\nwrite=\nhost=\naccess=local,remote\n\n");
    break;
  }
  return 0;
}

char*
msql_binary()
{
  return msqldbname;
}

static first = 1;

char*
create_passwd()
{
  if(first) {
    first = 0;
    return "-c ../.htpasswd";
  }
  return "../.htpasswd";
}

char*
msql_current(argc,argv)
     int argc;
     char** argv;
{
  if(strcmp(argv[0],msqldbname) == 0) return "1";
  else return "0";
}

char*
action()
{
  return currentaction;
}

char*
command()
{
  return msqlcommand;
}
